aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorAndreas L. Delmelle <adelmelle@apache.org>2005-03-21 20:17:15 +0000
committerAndreas L. Delmelle <adelmelle@apache.org>2005-03-21 20:17:15 +0000
commit3c3994c7c1ad8b780dcab94db9f31107f5badd7e (patch)
tree48e485fd7216b9ba347e9a6df8bfa8503007142d
parentb07d1e9f451ea58d42594f7da965370902f3613b (diff)
downloadxmlgraphics-fop-3c3994c7c1ad8b780dcab94db9f31107f5badd7e.tar.gz
xmlgraphics-fop-3c3994c7c1ad8b780dcab94db9f31107f5badd7e.zip
PR:
Obtained from: Submitted by: Reviewed by: Added 'hyphenation-jar' build target, Upated startup scripts to include the compiled jar-file git-svn-id: https://svn.apache.org/repos/asf/xmlgraphics/fop/trunk@198532 13f79535-47bb-0310-9956-ffa450edef68
-rw-r--r--build.xml18
-rw-r--r--fop.bat4
-rwxr-xr-xfop.sh11
3 files changed, 28 insertions, 5 deletions
diff --git a/build.xml b/build.xml
index 67775956d..b67bd4d9b 100644
--- a/build.xml
+++ b/build.xml
@@ -124,6 +124,7 @@ list of possible build targets.
<path refid="libs-basic-run-classpath"/>
<fileset dir="${basedir}/build">
<include name="fop.jar"/>
+ <include name="fop-hyph.jar" />
</fileset>
</path>
@@ -187,7 +188,7 @@ list of possible build targets.
<property name="xdocs.dir" value="${src.dir}/documentation/content/xdocs"/>
<property name="fo.examples.dir" value="${basedir}/examples/fo/basic"/>
<property name="lib.dir" value="${basedir}/lib"/>
- <property name="hyph.dir" value="${src.dir}/hyph"/>
+ <property name="hyph.dir" value="${basedir}/hyph"/>
<property name="conf.dir" value="${basedir}/conf"/>
<property name="packages" value="org.apache.fop.*"/>
@@ -484,6 +485,17 @@ list of possible build targets.
targetDir="${user.hyphdest.dir}"/>
</target>
+ <target name="hyphenation-jar" depends="hyphenation">
+ <jar jarfile="${build.dir}/fop-hyph.jar" basedir="${build.dest}" includes="hyph/**">
+ <manifest>
+ <attribute name="Implementation-Title" value="${Name}"/>
+ <attribute name="Implementation-Version" value="${version}"/>
+ <attribute name="Implementation-Vendor" value="The Apache Software Foundation (http://xml.apache.org/fop/)"/>
+ <attribute name="Build-Id" value="${ts} (${user.name} [${os.name} ${os.version} ${os.arch}, Java ${java.runtime.version}])"/>
+ </manifest>
+ </jar>
+ </target>
+
<target name="uptodate-jar" depends="compile, hyphenation">
<uptodate property="jar.uptodate" targetfile="${build.dir}/${name}.jar">
<srcfiles dir= "${build.dest}"/>
@@ -492,7 +504,7 @@ list of possible build targets.
<!-- =================================================================== -->
<!-- Creates the class package -->
<!-- =================================================================== -->
- <target name="package" depends="compile,hyphenation,uptodate-jar" description="Generates the jar files" unless="jar.uptodate">
+ <target name="package" depends="compile,hyphenation-jar,uptodate-jar" description="Generates the jar files" unless="jar.uptodate">
<echo message="Creating the jar file ${build.dir}/${name}.jar"/>
<tstamp>
@@ -504,7 +516,7 @@ list of possible build targets.
<map from="${optional.lib.dir}${file.separator}" to=""/>
</pathconvert>
- <jar jarfile="${build.dir}/${name}.jar" basedir="${build.dest}" includes="org/**,hyph/**">
+ <jar jarfile="${build.dir}/${name}.jar" basedir="${build.dest}" includes="org/**">
<manifest>
<attribute name="Main-Class" value="${main.class}"/>
<attribute name="Class-Path" value="${manifest-classpath}"/>
diff --git a/fop.bat b/fop.bat
index 459d3d164..eee662aed 100644
--- a/fop.bat
+++ b/fop.bat
@@ -37,7 +37,9 @@ rem Possible SimpleLog values: "trace", "debug", "info" (default), "warn", "err
rem set LOGLEVEL=-Dorg.apache.commons.logging.simplelog.defaultlog=INFO
set LIBDIR=%LOCAL_FOP_HOME%lib
+
set LOCALCLASSPATH=%LOCAL_FOP_HOME%build\fop.jar
+set LOCALCLASSPATH=%LOCALCLASSPATH%;%LOCAL_FOP_HOME%build\fop-hyph.jar
set LOCALCLASSPATH=%LOCALCLASSPATH%;%LIBDIR%\xml-apis.jar
set LOCALCLASSPATH=%LOCALCLASSPATH%;%LIBDIR%\xercesImpl-2.2.1.jar
set LOCALCLASSPATH=%LOCALCLASSPATH%;%LIBDIR%\xalan-2.4.1.jar
@@ -48,6 +50,8 @@ set LOCALCLASSPATH=%LOCALCLASSPATH%;%LIBDIR%\commons-logging-1.0.3.jar
set LOCALCLASSPATH=%LOCALCLASSPATH%;%LIBDIR%\jimi-1.0.jar
set LOCALCLASSPATH=%LOCALCLASSPATH%;%LIBDIR%\jai_core.jar
set LOCALCLASSPATH=%LOCALCLASSPATH%;%LIBDIR%\jai_codec.jar
+set LOCALCLASSPATH=%LOCALCLASSPATH%;%LIBDIR%\fop-hyph.jar
+set LOCALCLASSPATH=%LOCALCLASSPATH%;%FOP_HYPHENATION_PATH%
java %LOGCHOICE% %LOGLEVEL% -cp "%LOCALCLASSPATH%" org.apache.fop.apps.Fop %FOP_CMD_LINE_ARGS%
diff --git a/fop.sh b/fop.sh
index f19a7854d..5df50c073 100755
--- a/fop.sh
+++ b/fop.sh
@@ -46,6 +46,8 @@ fi
if $cygwin ; then
[ -n "$FOP_HOME" ] &&
FOP_HOME=`cygpath --unix "$FOP_HOME"`
+ [ -n "$FOP_HYPHENATION_PATH" ] &&
+ FOP_HYPHENATION_PATH=`cygpath --unix "$FOP_HYPHENATION_PATH"`
[ -n "$JAVA_HOME" ] &&
JAVA_HOME=`cygpath --unix "$JAVA_HOME"`
[ -n "$CLASSPATH" ] &&
@@ -75,8 +77,8 @@ if [ -n "$CLASSPATH" ] ; then
LOCALCLASSPATH=$CLASSPATH
fi
-# add fop.jar, which resides in $FOP_HOME/build
-LOCALCLASSPATH=${FOP_HOME}/build/fop.jar:$LOCALCLASSPATH
+# add fop.jar and fop-hyph.jar, which reside in $FOP_HOME/build
+LOCALCLASSPATH=${FOP_HOME}/build/fop.jar:${FOP_HOME}/build/fop-hyph.jar:$LOCALCLASSPATH
# add in the dependency .jar files, which reside in $FOP_HOME/lib
DIRLIBS=${FOP_HOME}/lib/*.jar
@@ -93,6 +95,11 @@ do
fi
done
+# add in user-defined hyphenation JARs
+if [ -n "$FOP_HYPHENATION_PATH" ] ; then
+ LOCALCLASSPATH=$LOCALCLASSPATH:$FOP_HYPHENATION_PATH
+fi
+
# For Cygwin, switch paths to Windows format before running java
if $cygwin; then
FOP_HOME=`cygpath --path --windows "$FOP_HOME"`